@@ -6,15 +6,16 @@ calc_MinDose3<- structure(function( # Apply the (un-)logged three parameter mini
   # ===========================================================================
   ##author<< 
   ## Christoph Burow, University of Cologne (Germany) \cr
-  ## Based on a rewritten script S script of Rex Galbraith, 2010 \cr\cr
+  ## Based on a rewritten S script of Rex Galbraith, 2010 \cr\cr
   
   ##section<<
-  ## version 0.1 [2013-09-04] 
+  ## version 0.2 [2013-11-04] 
   # ===========================================================================
   
   input.data, 
-  ### \code{\link{data.frame}} (\bold{required}): two column data frame with De
-  ### values and corresponding De errors
+  ### \code{\linkS4class{RLum.Results}} or \link{data.frame} (\bold{required}):
+  ### for \code{data.frame}: two columns with De \code{(input.data[,1])} and
+  ### De error \code{(values[,2])}
   sigmab, 
   ### \code{\link{numeric}}  (\bold{required}): spread in De values given as a 
   ### fraction (e.g. 0.2). This value represents the expected overdispersion in
@@ -37,7 +38,10 @@ calc_MinDose3<- structure(function( # Apply the (un-)logged three parameter mini
   init.sigma=1.2, 
   ### \code{\link{numeric}} (with default): starting value of sigma
   init.p0=0.01,
-  ### \code{\link{numeric}} (with default): starting value of p0 
+  ### \code{\link{numeric}} (with default): starting value of p0
+  ignore.NA = FALSE,
+  ### \code{\link{logical}} (with default): ignore NA values during log
+  ### likelihood calculations. See details.
   calc.ProfileLikelihoods=TRUE, 
   ### \code{\link{logical}} (with default): calculate profile log likelihood
   ### functions for gamma, sigma, p0. See \code{output.indices}.
@@ -52,7 +56,7 @@ calc_MinDose3<- structure(function( # Apply the (un-)logged three parameter mini
   output.filename="default", 
   ### \code{\link{character}} (with default): desired filename, else results 
   ### are saved to default-3R(-UL).res 
-  output.plot=FALSE, 
+  output.plot=TRUE, 
   ### \code{\link{logical}} (with default): plot output
   ### (\code{TRUE}/\code{FALSE})
   output.indices=3
@@ -66,21 +70,43 @@ calc_MinDose3<- structure(function( # Apply the (un-)logged three parameter mini
 ## CONSISTENCY CHECK OF INPUT DATA
 ##============================================================================##
   
-if(is.data.frame(input.data)==FALSE) { print("Input data needs to be of type 
-                                             data.frame",quote=F) 
-                                       stop(domain=NA) }
-try(colnames(input.data)<- c("ED","ED_Error"),silent=TRUE)
-if(colnames(input.data[1])!="ED"||colnames(input.data[2])!="ED_Error") { 
-  print("Columns must be named 'ED' and 'ED_Error'",quote=F)
-                                       stop(domain=NA) }
-if(sigmab <0 | sigmab >1) { print("sigmab needs to be given as a fraction 
-                                  between 0 and 1 (e.g. 0.2)",quote=F)
-                                       stop(domain=NA)}
-if(output.indices >3 | output.indices <1) { print("Invalid number of indices. 
-                                                  Only 1, 2 or 3 (gamma, 
-                                                  gamma/sigma, gamma/sigma/p0) 
-                                                  allowed.",quote=F)
-                                       stop(domain=NA)}
+  if(missing(input.data)==FALSE){
+    
+    if(is(input.data, "data.frame") == FALSE & is(input.data,
+                                                  "RLum.Results") == FALSE){
+      
+      stop("[calc_FiniteMixture] Error: 'input.data' object has to be of type 
+           'data.frame' or 'RLum.Results'!")
+      
+    }else{
+      
+      if(is(input.data, "RLum.Results") == TRUE){
+        
+        input.data <- get_RLum.Results(input.data, 
+                                       signature(object = "De.values"))
+        
+      }
+    }
+  }  
+  
+  try(colnames(input.data)<- c("ED","ED_Error"),silent=TRUE)
+  
+  if(colnames(input.data[1])!="ED"||colnames(input.data[2])!="ED_Error") { 
+    cat(paste("Columns must be named 'ED' and 'ED_Error'"), fill = FALSE)
+    stop(domain=NA) 
+  }
+  
+  if(sigmab <0 | sigmab >1) { 
+    cat(paste("sigmab needs to be given as a fraction between", 
+              "0 and 1 (e.g. 0.2)"), fill = FALSE)
+    stop(domain=NA)
+  }
+  
+  if(output.indices >3 | output.indices <1) { 
+    cat(paste("Invalid number of indices. Only 1, 2 or 3",
+              "(gamma, gamma/sigma, gamma/sigma/p0) allowed."), fill = FALSE)
+    stop(domain=NA)
+  }
   
 ##============================================================================##
 ## CALCULATIONS
@@ -89,8 +115,8 @@ if(output.indices >3 | output.indices <1) { print("Invalid number of indices.
 # this calculates ln(1-Phi(x)) robustly, where 
 # Phi(x) is the standard normal c.d.f
 
-lnnprob.f<- function(x)
-{ 
+lnnprob.f<- function(x) { 
+  
   logsqrt2pi<- 0.5*log(2*pi)
 
   b1  <-  3.8052e-8
@@ -107,22 +133,38 @@ lnnprob.f<- function(x)
   
   lnnp<- x
   tf<-  (x<1.28)
-  if(sum(tf)>0) 
-     {
-      z<- x[tf]
-      lnnp[tf]<- log(1-pnorm(z))
-     }
+  
+  if(ignore.NA == FALSE) {
+    if(any(is.na(tf) == TRUE)) {
+      cat(paste("\n WARNING: log likelihood calculation produced NA values.",
+                "\n  To omit NA values set ignore.NA = TRUE. Use with caution!"),
+          fill = FALSE)    
+    }
+  }
+  
+  if(ignore.NA == TRUE) {
+    if(any(is.na(tf) == TRUE)) {
+      tf<- na.omit(tf)
+      options(warn = -1)
+    }
+  }
+  
+  if(sum(tf)>0) {
+    z<- x[tf]
+    lnnp[tf]<- log(1-pnorm(z))
+  }
+  
   tf<- (!tf)
-  if(sum(tf)>0)
-     {
-      z<- x[tf]
-      fz <- 1/(z+b3+b4/(z-b5+b6/(z+b7-b8/(z+b9+b10/(z+b11)))))
-      hz <- 1.0/(1.0-b1/z+b2*fz/z)
-      lnnp[tf] <-  log(hz)-log(z)-0.5*z*z-logsqrt2pi
-     }
+  
+  if(sum(tf)>0) {
+    z<- x[tf]
+    fz <- 1/(z+b3+b4/(z-b5+b6/(z+b7-b8/(z+b9+b10/(z+b11)))))
+    hz <- 1.0/(1.0-b1/z+b2*fz/z)
+    lnnp[tf] <-  log(hz)-log(z)-0.5*z*z-logsqrt2pi
+  }
   return(lnnp)
 }
-	
+  
 # neglik.f calculates minus the log-likelihood of the data from 
 # the parameters and the data
 
@@ -168,23 +210,23 @@ neglik.f<- function(param,input.data,rep){
 	ipr<-    prstat[3]
 	ncalls<- ncalls+1
 	ncmod<- ncmod+1
+  
   if(console.extendedOutput==TRUE) {
-	if( ncmod==ipr | (ncalls==1 & ipr>0) )
-	   {
-	    cat(paste("\n\n\n ------ # function calls:", ncalls,"------"))
-	    cat(paste("\n neg. log likelihood: ",round(negll,3)))
-	    cat(paste("\n parameters"))
+    
+    if( ncmod==ipr | (ncalls==1 & ipr>0) ) {
+      cat(paste("\n\n\n ------ # function calls:", ncalls,"------"))
+      cat(paste("\n neg. log likelihood: ",round(negll,3)))
+      cat(paste("\n parameters"))
       cat(paste("\n  gamma: ",round(gamma,3),"  mindose:",
-              if(log==TRUE){round(exp(gamma),3)}else{round(gamma,3)}))
-	    cat(paste("\n  sigma: ",round(sigma,4)))
-	    cat(paste("\n     p0: ",round(p0,3)))
-	    cat(paste("\n      n: ",length(zi)))
-	    ncmod<- 0
-	   }
+                if(log==TRUE){round(exp(gamma),3)}else{round(gamma,3)}))
+      cat(paste("\n  sigma: ",round(sigma,4)))
+      cat(paste("\n     p0: ",round(p0,3)))
+      cat(paste("\n      n: ",length(zi)))
+      ncmod<- 0
+    }
   }
   
 	assign("prstat",c(ncalls,ncmod,ipr))
-
   return(negll)
 }
 
@@ -195,43 +237,54 @@ neglik.f<- function(param,input.data,rep){
 # read in the data and print the number of grains
   if(log==TRUE) { 
     lcd<- log(input.data$ED)
-    lse<-   sqrt( (input.data$ED_Error/input.data$ED)^2 + sigmab^2 )
-    }
+    lse<- sqrt((input.data$ED_Error/input.data$ED)^2 + sigmab^2)
+  }
   else {
     lcd<- input.data$ED
-    lse<-   sqrt( (input.data$ED_Error)^2 + sigmab^2 )
-    }
-
+    lse<- sqrt((input.data$ED_Error)^2 + sigmab^2)
+  }
+  
 	datmat<- cbind(lcd,lse)
 
+  
   cat("\n [Calc_MinDose3] \n")
 
 # supply the starting values and bounds for the parameters
-  if(log==TRUE) { gamma.init<- log(init.gamma) }
-  else {          gamma.init<- init.gamma }
+  if(log==TRUE) { 
+    gamma.init<- log(init.gamma) 
+  }
+  else {          
+    gamma.init<- init.gamma 
+  }
+  
   sigma.init<- init.sigma
   p0.init<- init.p0
-
   x0<- c(gamma.init, sigma.init, p0.init)
-  if(log==TRUE) { xlb<- c( log(gamma.xlb), sigma.xlb, 0.0001 )
-                  xub<- c( log(gamma.xub), sigma.xub, 0.9999 )
+  
+  if(log==TRUE) { 
+    xlb<- c( log(gamma.xlb), sigma.xlb, 0.0001 )
+    xub<- c( log(gamma.xub), sigma.xub, 0.9999 )
   }
-  else { xlb<- c( gamma.xlb, sigma.xlb, 0.0001 )
-         xub<- c( gamma.xub, sigma.xub, 0.9999 )
+  else { 
+    xlb<- c( gamma.xlb, sigma.xlb, 0.0001 )
+    xub<- c( gamma.xub, sigma.xub, 0.9999 )
   }
-
+  
 # parameters to control printing from nlminb
 	ncalls<- 0
 	ncmod<- 0
 	ipr<- 50
 	prstat<- c(ncalls,ncmod,ipr)
 	prfile<- F
-	if(log==TRUE) { Bmess<- 0 }
-
+  
+  if(log==TRUE) {
+    Bmess<- 0 
+  }
+  
 # maximise the likelihood
-  opt.param<- nlminb(start=x0,objective=neglik.f,scale=1,lower=xlb,upper=xub,
-                     input.data=datmat,control=list(iter.max = 1000, 
-                                                    eval.max = 1000))
+  opt.param<- nlminb(start=x0, objective=neglik.f, scale=1, lower=xlb,
+                     upper=xub, input.data=datmat,
+                     control=list(iter.max = 1000, eval.max = 1000))
 
 # print out the maxmimum likelihood estimates
   mlest<- opt.param$par
@@ -243,378 +296,383 @@ neglik.f<- function(param,input.data,rep){
 	bic<- -2*maxlik + 3*log(length(lcd))
   get("prstat",mode="numeric")
   ncalls<- prstat[1]
+  
   if(log==TRUE){
     get("Bmess",)
   }
-
+  
 # write the parameter estimates to output file filnam.res 
 # where filnam is the input file name
   
   filnam<- output.filename
 
-  if(output.file==TRUE)
-  {
-  lbout<- paste(filnam,if(log==TRUE){"-3R.res"}else{"-3R-UL.res"},sep="")
-  
-  write(c("Sample: ", filnam, "\nSigma_b: ", sigmab), file=lbout, ncolumns=2,
-        append=F)
-  write("",lbout,append=T)
-  write(paste("Final estimate of model parameters"),lbout,append=T)
-  write(paste("gamma:", round(gamma,3), "sigma:", round(sigma,3), "p0:",
-              round(p0,3)),lbout,append=T)
-  
-  write("\nmaximum likelihood estimate of minimum age",lbout, append=T)
-  
-  write(if(log==TRUE){exp(gamma)}else{gamma},lbout,append=T)
-
-
-# write fitted values to output file filnam-3R.res 
-# where filnam is the input file name
-  prfile<- T
-  neglik.f(mlest,datmat)
-  prfile<- F
-  
+  if(output.file==TRUE) {
+    lbout<- paste(filnam,if(log==TRUE){"-3R.res"}else{"-3R-UL.res"},sep="")
+    
+    write(c("Sample: ", filnam, "\nSigma_b: ", sigmab), file=lbout, ncolumns=2,
+          append=F)
+    write("",lbout,append=T)
+    write(paste("Final estimate of model parameters"),lbout,append=T)
+    write(paste("gamma:", round(gamma,3), "sigma:", round(sigma,3), "p0:",
+                round(p0,3)),lbout,append=T)
+    
+    write("\nmaximum likelihood estimate of minimum age",lbout, append=T)
+    
+    write(if(log==TRUE){exp(gamma)}else{gamma},lbout,append=T)
+    
+    
+    # write fitted values to output file filnam-3R.res 
+    # where filnam is the input file name
+    prfile<- T
+    neglik.f(mlest,datmat)
+    prfile<- F
   }
-
+  
 ##============================================================================##
 ## PROFILE LOG LIKELIHOODS
 ##============================================================================##
 
-  if(calc.ProfileLikelihoods==TRUE)
-  {
+  if(calc.ProfileLikelihoods==TRUE) {
 
-# read in the indices of the parameters for which profile
-# likelihoods are to be calculated
-  
-  profind<- as.integer(output.indices)
-
-# open a postscript file called filnam-3R.ps to plot the profiles
-# and set graphical parameters		
-  if(output.plot==TRUE) {
-  postscript(file=paste(filnam,if(log==TRUE){"-3R.ps"}else{"-3R-UL.ps"},sep=""),
-             horizontal=F)
-       par(mfrow=c(2,2),oma=c(9,2,9,1),mar=c(3.7,3.1,1.1,0.2),
-	      mgp=c(1.75,0.5,0),las=1,cex.axis=1.1,cex.lab=1.3)
-  }
-
-# calculate the required profiles
-  lbpar<- c("gamma","sigma","p0")
-  npar<- length(x0)
-  for(j in 1:profind)
-    {
+    # read in the indices of the parameters for which profile
+    # likelihoods are to be calculated
     
+    profind<- as.integer(output.indices)
+    
+    par(mfrow=c(2,2),oma=c(9,2,9,1),mar=c(3.7,3.1,1.1,0.2),
+        mgp=c(1.75,0.5,0),las=1,cex.axis=1.1,cex.lab=1.3)
+    
+    # calculate the required profiles
+    lbpar<- c("gamma","sigma","p0")
+    npar<- length(x0)
+    
+    for(j in 1:profind) {
+      
 ##============================================================================##    
 ## first pass at the profile likelihood
 
 # this does a broad sweep of the possible parameter values and
 # estimates where more intensive calculations should be made
-  lowpar<- xlb[j]+(mlest[j]-xlb[j])*c(0.01,0.5,0.8,0.9,0.95,0.99)
-  highpar<- mlest[j]+(xub[j]-mlest[j])*c(0.01,0.05,0.1,0.2,0.5,0.99)
-  prfpar<- c(lowpar,mlest[j],highpar)
-  plk<- numeric(0)
-
-  if(console.ProfileLikelihoods==TRUE){
-    cat("\n ------calculating profiles: broad sweep-------")
-    cat(paste("\n trial parameter value","|","profile log likelihood \n"))
-  }
-  for(par in prfpar)
-    {
-    
+      lowpar<- xlb[j]+(mlest[j]-xlb[j])*c(0.01,0.5,0.8,0.9,0.95,0.99)
+      highpar<- mlest[j]+(xub[j]-mlest[j])*c(0.01,0.05,0.1,0.2,0.5,0.99)
+      prfpar<- c(lowpar,mlest[j],highpar)
+      plk<- numeric(0)
+      
+      if(console.ProfileLikelihoods==TRUE) {
+        cat("\n ------calculating profiles: broad sweep-------")
+        cat(paste("\n trial parameter value","|","profile log likelihood \n"))
+      }
+      
+      for(par in prfpar) {
+        
 # set up the initial values and the bounds so that the 
 # profile parameter is fixed i.e. lower bd = upper bd
-  if(j==1) 
-    {
-      px0<- c(par,mlest[2:npar])
-      pxlb<- c(par,xlb[2:npar])
-      pxub<- c(par,xub[2:npar])
-     }
-  if(j>1 & j<npar) 
-    { 
-      j1<- j-1
-      j2<- j+1
-      px0<- c(mlest[1:j1],par,mlest[j2:npar])
-      pxlb<- c(xlb[1:j1],par,xlb[j2:npar])
-      pxub<- c(xub[1:j1],par,xub[j2:npar])
-     }
-  if(j==npar) 
-    { 
-      npar1<- npar-1
-      px0<- c(mlest[1:npar1],par)
-      pxlb<- c(xlb[1:npar1],par)
-      pxub<- c(xub[1:npar1],par)
-     }
-
+        if(j==1) {
+          px0<- c(par,mlest[2:npar])
+          pxlb<- c(par,xlb[2:npar])
+          pxub<- c(par,xub[2:npar])
+        }
+        
+        if(j>1 & j<npar) { 
+          j1<- j-1
+          j2<- j+1
+          px0<- c(mlest[1:j1],par,mlest[j2:npar])
+          pxlb<- c(xlb[1:j1],par,xlb[j2:npar])
+          pxub<- c(xub[1:j1],par,xub[j2:npar])
+        }
+        
+        if(j==npar) { 
+          npar1<- npar-1
+          px0<- c(mlest[1:npar1],par)
+          pxlb<- c(xlb[1:npar1],par)
+          pxub<- c(xub[1:npar1],par)
+        }
+        
 # parameters to control printing from nlminb
-  ncalls<-0
-  ncmod<- 0
-  ipr<- 0
-  prstat<- c(ncalls,ncmod,ipr)
-
-  # maximise the likelihood
-  opt.param<- nlminb(start=px0,objective=neglik.f,scale=1,lower=pxlb,upper=pxub,
-                     input.data=datmat,control=list(iter.max = 1000, 
-                                                    eval.max = 1000))
-
-  # save and print the results
-  proflik<- -maxlik-opt.param$objective
-  plk<- c(plk,proflik)
-  #
-  if(console.ProfileLikelihoods==TRUE){
-  cat(c("",format(round(j,0)),"   ",format(round(c(par,proflik),3),nsmall=3),
-        "\n"))
-  }
-}#END OF LOOP
-
+        ncalls<-0
+        ncmod<- 0
+        ipr<- 0
+        prstat<- c(ncalls,ncmod,ipr)
+        
+# maximise the likelihood
+        opt.param<- nlminb(start=px0, objective=neglik.f, scale=1, lower=pxlb,
+                           upper=pxub, input.data=datmat,
+                           control=list(iter.max = 1000, eval.max = 1000))
+        
+# save and print the results
+        proflik<- -maxlik-opt.param$objective
+        plk<- c(plk,proflik)
+        
+        if(console.ProfileLikelihoods==TRUE) {
+          cat(c("",format(round(j,0)),"   ", 
+                format(round(c(par, proflik), 3), nsmall=3), "\n"))
+        }
+      }#END OF LOOP
+      
 ##============================================================================##
 ## second pass
 
 # this does a fine sweep of the parameter values between
 # limits derived from the broad sweep
-  n<- length(prfpar)
-  cnt<- (1:n)
-  tf<- plk > -2.0
-  n1<- min(cnt[tf])
-  n2<- max(cnt[tf])
-  if(n1>1) tf[n1-1]<- T
-  if(n2<n) tf[n2+1]<- T
-  minpar<- xlb[j]
-  if(n1>1) minpar<- min(prfpar[tf])
-  maxpar<- xub[j]
-  if(n2<n) maxpar<- max(prfpar[tf])
-  prfpar2<- seq(minpar,maxpar,length=20)
-  plk2<- numeric(0)
-
-  if(console.ProfileLikelihoods==TRUE){
-  cat("\n ------calculating profiles: fine sweep-------")
-  cat(paste("\n trial parameter value","|","profile log likelihood \n"))
-  }
-  for(par in prfpar2 )
-    { 
-    
+      n<- length(prfpar)
+      cnt<- (1:n)
+      tf<- plk > -2.0
+      n1<- min(cnt[tf])
+      n2<- max(cnt[tf])
+      
+      if(n1>1) {
+        tf[n1-1]<- T
+      }
+      
+      if(n2<n) {
+        tf[n2+1]<- T
+      }
+     
+      minpar<- xlb[j]
+      
+      if(n1>1) {
+        minpar<- min(prfpar[tf])
+      }
+      
+      maxpar<- xub[j]
+      
+      if(n2<n) {
+        maxpar<- max(prfpar[tf])
+      }
+      
+      prfpar2<- seq(minpar,maxpar,length=20)
+      plk2<- numeric(0)
+      
+      if(console.ProfileLikelihoods==TRUE) {
+        cat("\n ------calculating profiles: fine sweep-------")
+        cat(paste("\n trial parameter value","|","profile log likelihood \n"))
+      }
+      
+      for(par in prfpar2) { 
+        
 # set up the initial values and the bounds so that the 
 # profile parameter is fixed i.e. lower bd = upper bd 
-  if(j==1) 
-    {
-      px0<- c(par,mlest[2:npar])
-      pxlb<- c(par,xlb[2:npar])
-      pxub<- c(par,xub[2:npar])
-    }
-  if(j>1 & j<npar) 
-    {
-      j1<- j-1
-      j2<- j+1
-      px0<- c(mlest[1:j1],par,mlest[j2:npar])
-      pxlb<- c(xlb[1:j1],par,xlb[j2:npar])
-      pxub<- c(xub[1:j1],par,xub[j2:npar])
-    }
-  if(j==npar) 
-    {
-      npar1<- npar-1
-      px0<- c(mlest[1:npar1],par)
-      pxlb<- c(xlb[1:npar1],par)
-      pxub<- c(xub[1:npar1],par)
-    }
-
-
+        if(j==1) {
+          px0<- c(par,mlest[2:npar])
+          pxlb<- c(par,xlb[2:npar])
+          pxub<- c(par,xub[2:npar])
+        }
+        
+        if(j>1 & j<npar) {
+          j1<- j-1
+          j2<- j+1
+          px0<- c(mlest[1:j1],par,mlest[j2:npar])
+          pxlb<- c(xlb[1:j1],par,xlb[j2:npar])
+          pxub<- c(xub[1:j1],par,xub[j2:npar])
+        }
+        
+        if(j==npar) {
+          npar1<- npar-1
+          px0<- c(mlest[1:npar1],par)
+          pxlb<- c(xlb[1:npar1],par)
+          pxub<- c(xub[1:npar1],par)
+        }
+        
+        
 # parameters to control printing from nlminb
-  ncalls<-0
-  ncmod<- 0
-  ipr<- 0
-  prstat<- c(ncalls,ncmod,ipr)
- 
+        ncalls<-0
+        ncmod<- 0
+        ipr<- 0
+        prstat<- c(ncalls,ncmod,ipr)
+        
 # maximise the likelihood
-  opt.param<- nlminb(start=px0,objective=neglik.f,scale=1,lower=pxlb,upper=pxub,
-                     input.data=datmat,control=list(iter.max = 1000, 
-                                                    eval.max = 1000))
-
+        opt.param<- nlminb(start=px0,objective=neglik.f,scale=1,lower=pxlb,upper=pxub,
+                           input.data=datmat,control=list(iter.max = 1000, 
+                                                          eval.max = 1000))
+        
 # save and print the results
-  proflik<- -maxlik-opt.param$objective
-  plk2<- c(plk2,proflik)
-  
-  if(console.ProfileLikelihoods==TRUE){
-    cat(c("",format(round(j,0)),"   ",format(round(c(par,proflik),3),nsmall=3),
-          "\n"))
-  }
-}#END OF LOOP
-
+        proflik<- -maxlik-opt.param$objective
+        plk2<- c(plk2,proflik)
+        
+        if(console.ProfileLikelihoods==TRUE){
+          cat(c("",format(round(j,0)),"   ",format(round(c(par,proflik),3),nsmall=3),
+                "\n"))
+        }
+      }#END OF LOOP
+      
 ##============================================================================##
 ## POOLING & PLOTTING
 ##============================================================================##
-  
+
 # the results from the broad sweep and the fine sweep
 # are pooled, and only the data values near the  maximum likelihood
-# solution are kept and the results are plotted in filnam-3R.ps
-  prfpar<- c(prfpar,prfpar2)
-  plk<- c(plk,plk2)
-  ord<- order(prfpar)
-  prfpar<- prfpar[ord]
-  plk<- plk[ord]
-  n<- length(prfpar)
-  cnt<- (1:n)
-  tf<- plk>=-1.92
-  n1<- min(cnt[tf])
-  n2<- max(cnt[tf])
-  if(n1>1) tf[n1-1]<- T
-  if(n2<n) tf[n2+1]<- T
-  prfpar<- prfpar[tf]
-  plk<- plk[tf]
-
+# solution are kept and the results are plotted
+      prfpar<- c(prfpar,prfpar2)
+      plk<- c(plk,plk2)
+      ord<- order(prfpar)
+      prfpar<- prfpar[ord]
+      plk<- plk[ord]
+      n<- length(prfpar)
+      cnt<- (1:n)
+      tf<- plk>=-1.92
+      n1<- min(cnt[tf])
+      n2<- max(cnt[tf])
+      if(n1>1) tf[n1-1]<- T
+      if(n2<n) tf[n2+1]<- T
+      prfpar<- prfpar[tf]
+      plk<- plk[tf]
+      
 # plotting
-  if(output.plot==TRUE) {
-  
-  plot(prfpar,plk,type="n",xlab=lbpar[j],ylab="",ylim=c(-2.5,0),cex=0.8)
-  lines(prfpar,plk)
-  abline(h=-1.92,lty=3)
-  abline(h=-0.5,lty=3)
-  
-  }
-
+      if(output.plot==TRUE) {
+        
+        plot(prfpar,plk,type="n",xlab=lbpar[j],ylab="",ylim=c(-2.5,0),cex=0.8)
+        lines(prfpar,plk)
+        abline(h=-1.92,lty=3)
+        abline(h=-0.5,lty=3)
+        
+      }
+      
 # the 95% upper and lower confidence limits are calculated from the
 # profile results  and the results are added to the plot
-  n<- length(prfpar)
-  cnt<- (1:n)
-  tf<- plk>=-1.92
-  n1<- min(cnt[tf])
-  n2<- max(cnt[tf])
-  delu<- (maxpar-minpar)/100
-  
+      n<- length(prfpar)
+      cnt<- (1:n)
+      tf<- plk>=-1.92
+      n1<- min(cnt[tf])
+      n2<- max(cnt[tf])
+      delu<- (maxpar-minpar)/100
+      
 # the lower confidence limit
-if(n1>1)
-  {
-    uci<-prfpar[(n1-1):n1]
-    lci<- plk[(n1-1):n1]
-    u1<- approx(lci,uci,-1.92)$y
-    
-    if(output.plot==TRUE) {
-      text(u1+delu,-2.12,format(round(u1,2)),adj=0,cex=1)
-      if(j==1 & log==TRUE)
-        {
-	        text(u1+delu,-2.32,format(round(exp(u1),2)),adj=0,cex=1)
+      if(n1>1)
+      {
+        uci<-prfpar[(n1-1):n1]
+        lci<- plk[(n1-1):n1]
+        u1<- approx(lci,uci,-1.92)$y
+        
+        if(output.plot==TRUE) {
+          text(u1+delu,-2.12,format(round(u1,2)),adj=0,cex=1)
+          if(j==1 & log==TRUE)
+          {
+            text(u1+delu,-2.32,format(round(exp(u1),2)),adj=0,cex=1)
+          }
         }
       }
-    }
 # the upper confidence limit
-  if(n2<n)
-    {
-      uci<-prfpar[n2:(n2+1)]
-      lci<- plk[n2:(n2+1)]
-      u2<- approx(lci,uci,-1.92)$y
-     	
-      if(output.plot==TRUE) {
-        text(u2-delu,-2.12,format(round(u2,2)),adj=1,cex=1)
-     	  if(j==1 & log==TRUE)
-         {
-	         text(u2-delu,-2.32,format(round(exp(u2),2)),adj=1,cex=1)
-         }
-       }
-     }
-  if(j==1) {
-  try(gul<- u1, silent=TRUE)
-  try(guu<- u2, silent=TRUE) }
-  
-  if(output.file==TRUE&&j==1) {
-  write("\n95% confidence interval",lbout,append=T)
-  if(log==TRUE) {
-    try(write(c(exp(u1),exp(u2)),lbout,append=T),silent=TRUE)
-    try(write(paste("-",round(exp(gamma)-exp(u1),2),"+",
-                    round(exp(u2)-exp(gamma),2)),lbout,append=T),silent=TRUE)
-  }
-  else {
-    try(write(c(u1,u2),lbout,append=T),silent=TRUE)
-    try(write(paste("-",round(gamma-u1,2),"+",round(u2-gamma,2)),lbout,
-              append=T), silent=TRUE)  
-  }
-  }
-  
+      if(n2<n)
+      {
+        uci<-prfpar[n2:(n2+1)]
+        lci<- plk[n2:(n2+1)]
+        u2<- approx(lci,uci,-1.92)$y
+        
+        if(output.plot==TRUE) {
+          text(u2-delu,-2.12,format(round(u2,2)),adj=1,cex=1)
+          if(j==1 & log==TRUE)
+          {
+            text(u2-delu,-2.32,format(round(exp(u2),2)),adj=1,cex=1)
+          }
+        }
+      }
+      if(j==1) {
+        try(gul<- u1, silent=TRUE)
+        try(guu<- u2, silent=TRUE) }
+      
+      if(output.file==TRUE&&j==1) {
+        write("\n95% confidence interval",lbout,append=T)
+        if(log==TRUE) {
+          try(write(c(exp(u1),exp(u2)),lbout,append=T),silent=TRUE)
+          try(write(paste("-",round(exp(gamma)-exp(u1),2),"+",
+                          round(exp(u2)-exp(gamma),2)),lbout,append=T),silent=TRUE)
+        }
+        else {
+          try(write(c(u1,u2),lbout,append=T),silent=TRUE)
+          try(write(paste("-",round(gamma-u1,2),"+",round(u2-gamma,2)),lbout,
+                    append=T), silent=TRUE)  
+        }
+      }
+      
 # the 68% upper and lower confidence limits are calculated from the
 # profile results  and the results are added to the plot
-  n<- length(prfpar)
-  cnt<- (1:n)
-  tf<- plk>=-0.5
-  n1<- min(cnt[tf])
-  n2<- max(cnt[tf])
-  delu<- (maxpar-minpar)/100
-
+      n<- length(prfpar)
+      cnt<- (1:n)
+      tf<- plk>=-0.5
+      n1<- min(cnt[tf])
+      n2<- max(cnt[tf])
+      delu<- (maxpar-minpar)/100
+      
 # the lower confidence limit
-  if(n1>1)
-    {
-      uci<-prfpar[(n1-1):n1]
-      lci<- plk[(n1-1):n1]
-      u1<- approx(lci,uci,-0.5)$y
-     	
-      if(output.plot==TRUE) {
-        text(u1+delu,-0.7,format(round(u1,2)),adj=0,cex=1)
-     	
-        if(j==1 & log==TRUE)
-         {
-          text(u1+delu,-0.9,format(round(exp(u1),2)),adj=0,cex=1)
-         }
-       }
-     }
-
-# the upper confidence limit
-  if(n2<n)
-    {
-      uci<-prfpar[n2:(n2+1)]
-      lci<- plk[n2:(n2+1)]
-      u2<- approx(lci,uci,-0.5)$y
-     	
-      if(output.plot==TRUE) {
-        text(u2-delu,-0.7,format(round(u2,2)),adj=1,cex=1)
-    	  if(j==1 & log==TRUE)
-        {
-	        text(u2-delu,-0.9,format(round(exp(u2),2)),adj=1,cex=1)
+      if(n1>1)
+      {
+        uci<-prfpar[(n1-1):n1]
+        lci<- plk[(n1-1):n1]
+        u1<- approx(lci,uci,-0.5)$y
+        
+        if(output.plot==TRUE) {
+          text(u1+delu,-0.7,format(round(u1,2)),adj=0,cex=1)
+          
+          if(j==1 & log==TRUE)
+          {
+            text(u1+delu,-0.9,format(round(exp(u1),2)),adj=0,cex=1)
+          }
         }
       }
-    }
-  
-  if(j==1) {
-  try(gll<- u1, silent=TRUE)
-  try(glu<- u2, silent=TRUE) }
-  
-  if(output.file==TRUE&&j==1) {
-  write("\n68% confidence interval",lbout,append=T)
-  if(log==TRUE) {
-    try(write(c(exp(u1),exp(u2)),lbout,append=T),silent=TRUE)
-    try(write(paste("-",round(exp(gamma)-exp(u1),2),"+",
-                    round(exp(u2)-exp(gamma),2)),lbout,append=T),silent=TRUE) }
-  else {
-    try(write(c(u1,u2),lbout,append=T),silent=TRUE)
-    try(write(paste("-",round(gamma-u1,2),"+",round(u2-gamma),2),lbout,
-              append=T),silent=TRUE) }
-  }
-  
-  
-# printing the maximum likelihood estimate on the graph
-  if(output.plot==TRUE) {
-    text(mlest[j],-0.17,format(round(mlest[j],2)),cex=1)
-       	 if(j==1 & log==TRUE)
-            {
-  	          text(mlest[j],-0.35,format(round(exp(mlest[j]),2)),cex=1)
-            } 
+      
+# the upper confidence limit
+      if(n2<n)
+      {
+        uci<-prfpar[n2:(n2+1)]
+        lci<- plk[n2:(n2+1)]
+        u2<- approx(lci,uci,-0.5)$y
+        
+        if(output.plot==TRUE) {
+          text(u2-delu,-0.7,format(round(u2,2)),adj=1,cex=1)
+          if(j==1 & log==TRUE)
+          {
+            text(u2-delu,-0.9,format(round(exp(u2),2)),adj=1,cex=1)
+          }
         }
+      }
+      
+      if(j==1) {
+        try(gll<- u1, silent=TRUE)
+        try(glu<- u2, silent=TRUE) }
+      
+      if(output.file==TRUE&&j==1) {
+        write("\n68% confidence interval",lbout,append=T)
+        if(log==TRUE) {
+          try(write(c(exp(u1),exp(u2)),lbout,append=T),silent=TRUE)
+          try(write(paste("-",round(exp(gamma)-exp(u1),2),"+",
+                          round(exp(u2)-exp(gamma),2)),lbout,append=T),silent=TRUE) }
+        else {
+          try(write(c(u1,u2),lbout,append=T),silent=TRUE)
+          try(write(paste("-",round(gamma-u1,2),"+",round(u2-gamma),2),lbout,
+                    append=T),silent=TRUE) }
+      }
+      
+      
+# printing the maximum likelihood estimate on the graph
+      if(output.plot==TRUE) {
+        text(mlest[j],-0.17,format(round(mlest[j],2)),cex=1)
+        if(j==1 & log==TRUE)
+        {
+          text(mlest[j],-0.35,format(round(exp(mlest[j]),2)),cex=1)
+        } 
+      }
+    }
+    if(output.plot==TRUE) {
+      mtext(side=2,line=0,"relative profile log likelihood",cex=1.2,outer=T,las=0)
+      mtext(side=3,line=0,paste(filnam,if(log==TRUE){"   MAM 3"}
+                                else{"   MAM 3-UL"}),cex=1.4,outer=T)
     }
-  if(output.plot==TRUE) {
-    mtext(side=2,line=0,"relative profile log likelihood",cex=1.2,outer=T,las=0)
-    mtext(side=3,line=0,paste(filnam,if(log==TRUE){"   MAM 3"}
-                              else{"   MAM 3-UL"}),cex=1.4,outer=T)
-  }
 # Bmess is a message: it is the number ofs times 
 # B1<=B2 
-  if(log==TRUE) {
-  get("Bmess")
-  cat("\n -----------------------------")
-  cat(paste("\n # number of times B1<=B2:",Bmess,"#"))
-  cat("\n -----------------------------")
-  }
-}#EndOf IF (PROFILE LOG LIKELIHOODS)
-
+    if(log==TRUE) {
+      get("Bmess")
+      cat("\n -----------------------------")
+      cat(paste("\n # number of times B1<=B2:",Bmess,"#"))
+      cat("\n -----------------------------")
+    }
+  }#EndOf IF (PROFILE LOG LIKELIHOODS)
+  
   if(output.file==TRUE) {
-  write("",lbout,append=T)
-  write(paste("Likelihood: ", round(maxlik, 5)),lbout, append=T)
-  write(paste("       BIC: ", round(bic, 3)),lbout, append=T)
+    write("",lbout,append=T)
+    write(paste("Likelihood: ", round(maxlik, 5)),lbout, append=T)
+    write(paste("       BIC: ", round(bic, 3)),lbout, append=T)
   }
-
+  
 
 # prepare return values
 results<- data.frame(id=sample.id,n=length(lcd),log=log,Lmax=maxlik,BIC=bic,
@@ -672,51 +730,57 @@ try(results$"X95ci_upper"<- if(log==TRUE){exp(guu)}else{guu},silent=TRUE)
   }
 
   cat(paste("\n----------------------------------------------"))
-                 
-
-# close the postscript file
-  if(output.plot==TRUE) {
-  dev.off()
-  }
 
 # Print out warnings with regard to parameter boundaries
 
-bcheck<- data.frame(gamma=c(all.equal(gamma.xub,if(log==TRUE){exp(gamma)}
-                                      else{gamma})==TRUE,
-                            all.equal(gamma.xlb,if(log==TRUE){exp(gamma)}
-                                      else{gamma})==TRUE),
-                    sigma=c(all.equal(sigma.xub,sigma)==TRUE,
-                            all.equal(sigma.xlb,sigma)==TRUE))
-rownames(bcheck)<- c(".xub",".xlb")
+  bcheck<- data.frame(gamma=c(all.equal(gamma.xub,if(log==TRUE){exp(gamma)}
+                                        else{gamma})==TRUE,
+                              all.equal(gamma.xlb,if(log==TRUE){exp(gamma)}
+                                        else{gamma})==TRUE),
+                      sigma=c(all.equal(sigma.xub,sigma)==TRUE,
+                              all.equal(sigma.xlb,sigma)==TRUE))
+  rownames(bcheck)<- c(".xub",".xlb")
 
 
                     
-if(any(bcheck==TRUE)) {
-  cat(paste("\n\n #---------------------------------#"))
-  cat(paste("\n # Warning! One or more parameters #
- # are on the boundary. Check the  #
- # logical matrix below to see     #
- # which ones and where.           #"))
-  cat(paste("\n #---------------------------------#\n\n"))
-  print(bcheck)
-}
-
+  if(any(bcheck==TRUE)) {
+    cat(paste("\n\n #---------------------------------#"))
+    cat(paste("\n # Warning! One or more parameters #",
+              "\n # are on the boundary. Check the  #",
+              "\n # logical matrix below to see     #",
+              "\n # which ones and where.           #"), fill = FALSE)
+    cat(paste("\n #---------------------------------#\n\n"))
+    print(bcheck)
+  }
+  
+  if(ignore.NA == TRUE) {
+    cat(paste("\n CAUTION: By ignoring NA values the validity of results",
+              "is not ensured. \n"), fill = FALSE)
+  }
 
 # return values
-
-invisible(list(results=results))
-### A terminal output is provided. A plot (\link{postscript}) and a file 
-### containing statistical results are provided if desired. In addition a list 
-### is returned containing the following element: \cr\cr
-### \code{results} data frame containing statistical results.
-
+  newRLumResults.calc_MinDose3 <- set_RLum.Results(
+    data = list(
+      results = results))
+  
+  invisible(newRLumResults.calc_MinDose3)
+  ### Returns a plot (optional) and terminal output. A file 
+  ### containing statistical results is provided if desired. In addition an 
+  ### \code{\linkS4class{RLum.Results}} object is 
+  ### returned containing the following element:
+  ###
+  ### \item{results}{\link{data.frame} with statistical parameters.}
+  ###
+  ### The output should be accessed using the function 
+  ### \code{\link{get_RLum.Results}}  
+  
 ##details<<
 ## \bold{Parameters} \cr\cr
-## This model has three parameters: 
+## This model has three parameters: \cr
 ## \tabular{rl}{
 ## \code{gamma}: \tab minimum dose on the log scale \cr
 ## \code{sigma}: \tab spread in ages above the minimum \cr
-## \code{p0}: \tab proportion of grains at gamma}
+## \code{p0}: \tab proportion of grains at gamma \cr }
 ## \bold{(Un-)logged model} \cr\cr
 ## In the original version of the three-parameter minimum dose model, the basic
 ## data are the natural logarithms of the De estimates and relative standard 
@@ -740,7 +804,15 @@ invisible(list(results=results))
 ## \bold{Initial values} \cr\cr
 ## The log likelihood calculations use the \link{nlminb} function. Accordingly,
 ## initial values for the three parameters \code{init.gamma}, \code{init.sigma} 
-## and \code{init.p0} need to be specified.
+## and \code{init.p0} need to be specified. \cr\cr
+## \bold{Ignore NA values} \cr\cr
+## In some cases during the calculation of the log likelihoods, \code{NA} values 
+## are produced instantly terminating the minimum age model. It is advised to 
+## adjust some of the values provided for any argument. If the model still
+## produces NA values it is possible to omit these values by setting 
+## \code{ignore.NA = TRUE}. While the model is then usually able to finish
+## all calculations the integrity of the final estimates cannot be ensured.
+## Use this argument at your own risk.
 
 ##references<<
 ## Arnold, L.J., Roberts, R.G., Galbraith, R.F. & DeLong, S.B., 2009. A revised
@@ -780,7 +852,7 @@ invisible(list(results=results))
 ## applied.
 
 ##seealso<<
-## \code{\link{nlminb}}, \code{\link{postscript}}, 
+## \code{\link{nlminb}}, 
 ## \code{\link{calc_CentralDose}},
 ## \code{\link{calc_CommonDose}}, \code{\link{calc_FiniteMixture}},
 ## \code{\link{calc_FuchsLang2001}}, \code{\link{calc_MinDose4}}
