@@ -1,20 +1,35 @@
-##//////////////////////////////////////////////////////////////////////////////
-##//writeR2BIN.R
-##//////////////////////////////////////////////////////////////////////////////
-##==============================================================================
-##author: Sebastian Kreutzer
-##organisation: Freiberg Instruments/JLU Giessen
-##version: 0.1
-##date: 2013-09-21
-##==============================================================================
-##
+writeR2BIN <- structure(function(#Export Risoe.BINfileData into Risoe BIN-file
+  ### Exports a Risoe.BINfileData object in a *.bin or *.binx file that can be 
+  ### opened by the Analyst software or other Risoe software.
+  
+  # ===========================================================================
+  ##author<<
+  ## Sebastian Kreutzer, Freiberg Instruments/JLU Giessen (Germany)
+  
+  ##section<<
+  ## version 0.1
+  # ===========================================================================
 
+  object,
+  ## \code{\linkS4class{Risoe.BINfileData}} (\bold{required}): input object
+  ## to be stored in a bin file.
+  
+  file,
+  ## \code{\link{character}} (\bold{required}): file name and path of the 
+  ## output file\cr
+  ## [WIN]: \code{writeR2BIN(object, "C:/Desktop/test.bin")}, \cr  
+  ## [MAC/LINUX]: \code{writeR2BIN("/User/test/Desktop/test.bin")}
+  
+  version,
+  ## \code{\link{raw}} (optional): version number for the output file.
+  ## If no value is provided the highest version number from the 
+  ## \code{\linkS4class{Risoe.BINfileData}} is taken automatically.\cr\cr
+  ## Note: This argument can be used to convert BIN-file versions.
+  
+  txtProgressBar = TRUE
+  ## \link{logical} (with default): enables or disables \code{\link{txtProgressBar}}. 
 
-writeR2BIN <- function(object,
-                       file,
-                       version,
-                       txtProgressBar = TRUE
-                       ){
+){
   
 # Config ------------------------------------------------------------------  
   
@@ -884,5 +899,40 @@ while(ID<=n.records) {
 ##output
 cat(paste("\t >> ",ID-1,"records have been written successfully!\n\n",paste=""))
 
+# DOCUMENTATION - INLINEDOC LINES -----------------------------------------
 
-}#end function
+  ##details<<
+  ## The structure of the exported binary data follows the data structure 
+  ## published in the Appendices of the Analyst manual p. 42.\cr\cr
+  ## If \code{LTYPE}, \code{DTYPE} and \code{LIGHTSOURCE} are not of type 
+  ## \code{\link{character}}, no transformation into numeric values is done. 
+
+  ##value<<
+  ## Write a binary file.
+
+  ##references<<
+  ## Duller, G., 2007. Analyst. 
+
+  ##note<<
+  ## The function just roughly checks the data structures. 
+  ## The validity of the output data depends on the user.\cr\cr
+  ## The validity of the file path is not further checked. \cr 
+  ## BIN-file conversions using the argument \code{version} may be a lossly conversion, 
+  ## depending on the chosen input and output data 
+  ## (e.g. conversion from version 06 to 04).
+
+  ##seealso<<
+  ## \code{\link{readBIN2R}}, \code{\linkS4class{Risoe.BINfileData}},
+  ## \code{\link{writeBin}}
+
+  ##keyword<<
+  ## IO
+
+}, ex=function(){
+  
+  ##uncomment for usage 
+  
+  ##data(ExampleData.BINfileData, envir = environment())
+  ##writeR2BIN(CWOSL.SAR.Data, file="[your path]/output.bin")
+  
+})  
